@@ -260,7 +260,8 @@ covid19.JHU.data <- function(case='aggregated', local.data=FALSE, debrief=FALSE,
                         # aggregated data
                         # 'aggregated'   = paste0(LOCAL.repo,format(Sys.Date()-1,format="%m-%d-%Y"),".csv"),
 			# 'aggregated'   = paste0(LOCAL.repo,"03-24-2020.csv"),
-			'aggregated'   = system.file("extdata","09-15-2020.csv.RDS", package=covid19.pckg, mustWork = TRUE),
+			# 'aggregated'   = system.file("extdata","09-15-2020.csv.RDS", package=covid19.pckg, mustWork = TRUE),
+			'aggregated'   = system.file("extdata","latest.RDS", package=covid19.pckg, mustWork = TRUE),
                         # GLOBAL TimeSeries cases
                         # 'ts-confirmed' = paste0(LOCAL.repo,"time_series_covid19_confirmed_global.csv"),
                         # 'ts-deaths'    = paste0(LOCAL.repo,"time_series_covid19_deaths_global.csv"),
@@ -352,191 +353,14 @@ covid19.JHU.data <- function(case='aggregated', local.data=FALSE, debrief=FALSE,
 	# will load data from local source
 	return( covid19.data(case,local.data=TRUE) )
 	}
-
+                # debriefing...
+                debriefing(covid19.cases,debrief)
 }
 
+
 ###########################################################################
 
 
-covid19.Toronto.data <- function(data.fmt="TS",local.data=FALSE,debrief=FALSE, OLD.fmt=FALSE, acknowledge=FALSE) {
-#' function to import data from the city of Toronto, ON - Canada
-#' as reported by the City of Toronto
-#'	https://www.toronto.ca/home/covid-19/covid-19-latest-city-of-toronto-news/covid-19-status-of-cases-in-toronto/
-#'
-#' @param  data.fmt  "TS" for TimeSeries of cumulative cases or "original" for the data as reported in the google-document with multiple sheets
-#' @param  local.data  boolean flag to indicate whether the data will be read from the local repo, in case of connectivity issues or data integrity
-#' @param  debrief  boolean specifying whether information about the read data is going to be displayed in screen
-#' @param  OLD.fmt  boolean flag to specify if the data is being read in an old format
-#' @param  acknowledge  boolean flag to indicate that the user acknowledges where the data is coming from.  If FALSE, display data acquisition messages.
-#'
-#' @return  a dataframe (or a list in the case of "original") with the latest data reported for the city of Toronto, ON - Canada
-#'
-#' @importFrom  utils  download.file
-#' @importFrom  readxl  excel_sheets read_excel
-#'
-#' @export
-#'
-	loadLibrary("readxl")
-
-	# identify source of the data
-	if (!local.data) {
-		# Google drive URL, with "City of Toronto" data
-		city.of.Toronto.data <- "https://drive.google.com/uc?export=download&id=1euhrML0rkV_hHF1thiA0G5vSSeZCqxHY"
-		# temporary file to retrieve data, does not exist yet ==> mustwork=FALSE to avoid warning message
-		Tor.xlsx.file <- normalizePath(file.path(tempdir(), "covid19-toronto.xslx"), mustWork=FALSE)
-		if (!acknowledge) {
-		  header('',paste("Accessing file from...",Tor.xlsx.file))
-		}
-
-		# save excel file
-		#if (capabilities('libcurl')) {
-		#	dwnld.method <- 'libcurl'
-		#} else {
-		#	stop("curl/libcurl; needed to download data from internet")
-		#}
-		download.file(city.of.Toronto.data, destfile=Tor.xlsx.file, mode = 'wb' )	#method=dwnld.method)
-        } else {
-                # use local data
-  		covid19.pckg <- 'covid19.analytics'
-  		if (!acknowledge) {
-    		message("Data being read from *local* repo in the '",covid19.pckg,"' package")
-        header('~')
-  		}
-      Tor.xlsx.file <- system.file("extdata","covid19_Toronto.xlsx", package=covid19.pckg, mustWork = TRUE)
-    }
-
-
-	if (file.exists(Tor.xlsx.file)) {
-		###~~~~~~
-		#print(Tor.xlsx.file)
-		###~~~~~~
-		# obtain names of sheets
-		lst.sheets <- excel_sheets(Tor.xlsx.file)
-
-		#print(lst.sheets)
-
-		# if only "TS" identify corresponding sheet
-		key.wrd <- "Cumulative Cases by Reported"
-		tgt.sheet <- pmatch(key.wrd,lst.sheets)
-		#if (is.na(tgt.sheet)) {
-		#	#key.wrd <- "Cases by Episode Date"
-		#	#tgt.sheet <- pmatch(key.wrd,lst.sheets)
-		#	covid19.Toronto.data(data.fmt,local.data=TRUE,debrief, OLD.fmt, acknowledge)
-		#}
-
-		# read data
-		if (toupper(data.fmt)=="TS") {
-			# check that the target sheet was found
-			if (!is.na(tgt.sheet)) {
-			  if (!acknowledge) {
-			    header('',"Reading TimeSeries data...")
-			  }
-				toronto <- read_excel(Tor.xlsx.file,sheet=tgt.sheet)
-			} else {
-				message(key.wrd, " NOT FOUND!")
-				toronto.loc <- covid19.Toronto.data(data.fmt,local.data=TRUE,debrief=debrief, OLD.fmt, acknowledge=acknowledge)
-				return(toronto.loc)
-			}
-		} else {
-			  if (!acknowledge) {
-			    header('',"Collecting all data reported...")
-			  }
-			toronto <- list()
-			# iterate on each sheet...
-			for (sht in lst.sheets) {
-				toronto[[sht]] <- read_excel(Tor.xlsx.file,sheet=sht)
-			}
-		}
-
-		# clean-up after reading the file only if it isn't the local repo
-		if (!local.data) file.remove(Tor.xlsx.file)
-	} else {
-		if (!local.data) {
-			warning("Could not access data from 'City of Toronto' source, attempting to reach local repo")
-			toronto.loc <- covid19.Toronto.data(data.fmt=data.fmt,local.data=TRUE,debrief=debrief, OLD.fmt, acknowledge=acknowledge)
-			return(toronto.loc)
-		} else {
-			stop("An error occurred accessing the data for the City of Toronto")
-		}
-	}
-
-
-	if (toupper(data.fmt)=="TS") {
-		## PREVIOUS FORMAT -- cases identified in 3 categories: deaths, active, resolved
-		if (OLD.fmt) {
-			# identify columns
-			cat.col <- 2
-			date.col <- 1
-			nbr.col <- 3
-
-			# filter categories
-			categs <- unique(toronto[[cat.col]])
-			# sort them alphabetically
-			categs <- sort(categs)
-
-			# check for inconsistencies in data, ie. missing categories
-			if (length(categs) != 3) {
-				stop("There supppose to be at least three categories/status within the data!\n This may represent some inconsistency with the datasets please contact the author of the package.")
-			}
-
-			# break into different categories
-			data.per.categ <- split(toronto, toronto[[cat.col]])
-
-			# Convert into TS format
-			x <- data.frame()
-			for (i in categs) {
-				reported.dates <- rev(unique(as.Date(data.per.categ[[i]][[date.col]])))
-				x <- rbind(x,rev(data.per.categ[[i]][[nbr.col]]))
-			}
-		###########
-		} else {
-		###########
-			date.col <- 1
-			categs <- names(toronto[2:4])
-
-			# get the dates...
-			reported.dates <- rev(unique(as.Date(toronto[,date.col][[1]])))
-
-			x <- data.frame()
-			# Convert into TS format
-			for (i in categs) {
-				#reported.dates <- rev(unique(as.Date(data.per.categ[[i]][[date.col]])))
-				#x <- rbind(x,rev(data.per.categ[[i]][[nbr.col]]))
-				data.per.categ <- toronto[,i]
-				x <- rbind(x,rev(data.per.categ[[1]]))
-			}
-		}
-
-		# add category
-		x <- cbind(x, categs)
-
-		## OLD WAY!!!! ###
-		#reported.dates <- rev(as.Date(toronto[[date.col]]))
-		#reported.cases <- rev(toronto[[nbr.col]])
-		#
-		#tor.data <- cbind(data.frame("Canada","Toronto, ON",43.6532,79.3832),
-		#				rbind(as.integer(reported.cases)) )
-		##################
-
-		tor.data <- cbind(data.frame("Canada","Toronto, ON",43.6532,79.3832), x)
-
-		names(tor.data) <- c("Country.Region","Province.City","Lat","Long",
-					as.character(reported.dates),
-					"status")
-	} else {
-		# ALL DATA
-		tor.data <- toronto
-		print(names(tor.data))
-	}
-
-	# debrief...
-	debriefing(tor.data,debrief)
-
-
-	return(tor.data)
-}
-
-
 # wrapper function around the covid19.data() function
 covid19.US.data <- function(local.data=FALSE,debrief=FALSE,acknowledge=FALSE) {
 #' function to read the TimeSeries US detailed data
